@@ -1,16 +1,12 @@
 #AnyDBM handling from perlindex:
 # NDBM_File as LAST resort
 
-package
-    AnyDBM_File; # hide from indexer
+package AnyDBM_File;
 use vars '@ISA';
-my @try = qw(DB_File GDBM_File SDBM_File ODBM_File NDBM_File) unless @ISA;
+@ISA = qw(DB_File GDBM_File SDBM_File ODBM_File NDBM_File) unless @ISA;
 my $mod;
-for $mod (@try) {
-    if (eval "require $mod") {
-	@ISA = $mod;
-	last;
-    }
+for $mod (@ISA) {
+    last if eval "require $mod"
 };
 
 package Tk::Pod::Search_db;
@@ -18,44 +14,31 @@ package Tk::Pod::Search_db;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 5.8 $ =~ /(\d+)\.(\d+)/);
+$VERSION = substr(q$Revision: 2.4 $, 10) . "";
 
 use Carp;
 use Fcntl;
-use File::Basename qw(dirname);
-use File::Spec;
 use Text::English;
 use Config;
 
-my $PREFIX = $Config::Config{prefix};
-# Bug in perlindex: because of assuming Unix directory separators the
-# index files are stored in man/man1, not in man on Windows:
-my $IDXDIR = $^O eq 'MSWin32' ? $Config::Config{man1dir} : dirname $Config::Config{man1dir};
+(my $PREFIX = $Config::Config{prefix}) =~ y|\\|/|d;
+(my $IDXDIR = $Config::Config{man1dir}) =~ s|/[^/]+$||;
 $IDXDIR ||= $PREFIX; # use perl directory if no manual directory exists
-# Debian uses a non-standard directory:
-if (-e "/etc/debian_version" && -d "/var/cache/perlindex") {
-    $IDXDIR = "/var/cache/perlindex";
-    # XXX What to do if perlindex is installed by the user and uses
-    # the man directory for storing the index files?
-}
-# Deliberately ignore the INDEXDIR environment variable which is used
-# by perlindex
 
 sub new {
     my $class = shift;
     my $idir  = shift;
+
     $idir ||= $IDXDIR;
+
     my (%self, %IF, %IDF, %FN);
-    my $if_file  = File::Spec->catfile($idir, "index_if");
-    tie (%IF,   'AnyDBM_File', $if_file,   O_RDONLY, 0644)
-        	or confess "Could not tie $if_file: $!\n".
-           	"Did you install Text::English and run 'perlindex -index'?\n";
-    my $idf_file = File::Spec->catfile($idir, "index_idf");
-    tie (%IDF,  'AnyDBM_File', $idf_file,   O_RDONLY, 0644)
-	       	or confess "Could not tie $idf_file: $!\n";
-    my $fn_file  = File::Spec->catfile($idir, "index_fn");
-    tie (%FN,   'AnyDBM_File', $fn_file,   O_RDONLY, 0644)
-	       	or confess "Could not tie $fn_file: $!\n";
+    tie (%IF,   'AnyDBM_File', "$idir/index_if",   O_RDONLY, 0644)
+        	or confess "Could not tie $idir/index_if: $!\n".
+            	"Did you run 'perlindex -index'?\n";
+    tie (%IDF,  'AnyDBM_File', "$idir/index_idf",   O_RDONLY, 0644)
+        	or confess "Could not tie $idir/index_idf: $!\n";
+    tie (%FN,   'AnyDBM_File', "$idir/index_fn",   O_RDONLY, 0644)
+        	or confess "Could not tie $idir/index_fn: $!\n";
 
     $self{IF}  = \%IF;
     $self{IDF} = \%IDF;
@@ -77,10 +60,10 @@ sub normalize {
     my @result;
 
     $line =~ tr/A-Z/a-z/;
-    $line =~ tr/a-z0-9_/ /cs;
+    $line =~ tr/a-z0-9/ /cs;
 
     my $word;
-    for $word (split / /, $line ) {
+    for $word (split ' ', $line ) {
         $word =~ s/^\d+//;
         next unless length($word) > 2;
         push @result, &Text::English::stem($word);
@@ -90,59 +73,44 @@ sub normalize {
 
 # changes for perlindex's search slightly modified
 sub searchWords {
-    my($self, $term, %args) = @_;
-
-    my @words = split / /, $term;
-
-    my $restrict_pod = $args{-restrictpod};
-    if (defined $restrict_pod) {
-	my(@modparts) = split /::/, $restrict_pod;
-	$restrict_pod = join('[/\\\\]', map { quotemeta } @modparts);
-    }
+    my $self = shift;
 
     #print "try words|", join('|',@_),"\n";
-    my $p = 'w';
     my %score;
-    my %termhits;
-    my $maxhits = 50;
+    my $maxhits = 15;
     my (@unknown, @stop);
 
     my $IF  = $self->{IF};
     my $IDF = $self->{IDF};
     my $FN  = $self->{FN};
 
-    #&initstop if $opt_verbose;
-    for my $word (normalize(@words)) {
+    #xxx &initstop if $opt_verbose;
+    my ($word, $did, %post); #xxx
+    for $word (normalize(@_)) {
         unless ($IF->{$word}) {
-#             if ($stop{$word}) {
-#                 push @stop, $word;
-#             } else {
-#                 push @unknown, $word;
-#             }
+            #xxxif ($stop{$word}) {
+            #xxx    push @stop, $word;
+            #xxx} else {
+            #xxx    push @unknown, $word;
+            #xxx}
             next;
         }
-        my %post = unpack($p.'*',$IF->{$word});
+        #my %post = unpack($p.'*',$IF->{$word});
+        %post = unpack('w*',$IF->{$word});
         my $idf = log($FN->{'last'}/$IDF->{$word});
-        for my $did (keys %post) {
-            my ($maxtf) = unpack($p, $FN->{$did});
-            $score{$did} = 0 unless defined $score{$did}; # perl -w 
+        for $did (keys %post) {
+            #xxx my ($maxtf) = unpack($p, $FN->{$did});
+            my ($maxtf) = unpack('w', $FN->{$did});
+            $score{$did} = 0 unless defined $score{$did}; # perl -w
             $score{$did} += $post{$did} / $maxtf * $idf;
-	    $termhits{$did}++;
         }
     }
 
     my @results;
-    for my $did (sort {	$termhits{$b} <=> $termhits{$a} || $score{$b} <=> $score{$a} } keys %score) {
-	my ($mtf, $path) = unpack($p.'a*', $FN->{$did});
-	# XXX Should not use Tk::Pod::Search::split_path, or split_path should be moved to another package
-	if ($restrict_pod) {
-	    my($check_path) = Tk::Pod::Search::split_path($path);
-	    next if $check_path !~ /^$restrict_pod/;
-	}
-	#next if ($restrict_pod && $path !~ /$restrict_pod/);
-	$path = File::Spec->catfile($self->prefix, $path) unless $^O eq 'MSWin32'; # This seems to be a perlindex bug in MSWin32
-	push @results, { termhits => $termhits{$did}, score => $score{$did}, path => $path };
-	last unless --$maxhits;
+    for $did (sort {$score{$b} <=> $score{$a}} keys %score) {
+            my ($mtf, $path) = unpack('wa*', $FN->{$did});
+            push @results, $score{$did}, $path;
+            last unless --$maxhits;
     }
 
     #print "results|", join('|',@results),"\n";
@@ -178,7 +146,7 @@ Tk::Pod::Search_db - dirty OO wrapper for C<perlindex>'s search functionality
 
 =head1 DESCRIPTION
 
-Module to search Pod documentation.  Before you can use
+Module to search POD documentation.  Before you can use
 the module one should create the indices with C<perlindex -index>.
 
 =head1 MISSING
@@ -208,7 +176,7 @@ or empty list if no match is found.
 =item $pathprefix = $idx->pathprefix()
 
 The return path prefix and C<$relpath> give together the full path
-name of the Pod documentation.
+name of the POD documentation.
 
 	$fullpath = $patchprefix . '/' . $relpath
 
@@ -219,7 +187,7 @@ index specific prefix handling is a mess up to know.
 
 =head1 SEE ALSO
 
-L<tkpod>, L<perlindex>, L<perlpod>, L<Tk::Pod::Search>
+tkpod, perlindex perlpod, Tk::Pod::Search
 
 =head1 AUTHORS
 
@@ -228,7 +196,7 @@ Achim Bohnet  <F<ach@mpe.mpg.de>>
 Most of the code here is borrowed from L<perlindex> written by
 Ulrich Pfeifer <F<Ulrich.Pfeifer@de.uu.net>>.
 
-Current maintainer is Slaven ReziE<0x0107> <F<slaven@rezic.de>>.
+Current maintainer is Slaven Rezic <F<slaven@rezic.de>>.
 
 Copyright (c) 1997-1998 Achim Bohnet. All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same
