@@ -4,14 +4,11 @@ use strict;
 package Tk::Pod::SimpleBridge;
 # Interface between Tk::Pod and Pod::Simple
 
-use vars qw($VERSION);
-$VERSION = '5.07';
-
 BEGIN {  # Make a DEBUG constant very first thing...
   if(defined &DEBUG) {
   } elsif(($ENV{'TKPODDEBUG'} || '') =~ m/^(\d+)/) { # untaint
-    my $debug = $1;
-    *DEBUG = sub () { $debug };
+    eval("sub DEBUG () {$1}");
+    die "WHAT? Couldn't eval-up a DEBUG constant!? $@" if $@;
   } else {
     *DEBUG = sub () {0};
   }
@@ -28,11 +25,12 @@ use vars qw(@ISA);
 sub no_op {return}
 
 sub process { # main routine: non-handler
-  my ($w,$file_or_textref, $title) = @_;  # window, filename or string ref, title (optional)
+  my ($w,$file) = @_;  # window, filename
+  die "WHAT? Null filename?" unless defined $file and length $file;
+  die "WHAT? Non-existent $file" unless -e $file and -f $file;
 
   my $p = $w->{'pod_parser'} = Pod::Simple::PullParser->new;
-  $p->set_source($file_or_textref);
-  my $file = !ref $file_or_textref && $file_or_textref;
+  $p->set_source($file);
 
   $w->toplevel->Busy;
   $w->init_styles;
@@ -43,27 +41,21 @@ sub process { # main routine: non-handler
 
   $w->{'sections'} = [];
   $w->{'pod_tag'} = '10000'; # counter
-#XXX  my $style_stack = $w->{'style_stack'} ||= []; # || is probably harmful
-  my $style_stack = $w->{'style_stack'} = [];
-
+  my $style_stack = $w->{'style_stack'} ||= [];
   my @pod_marks;
 
-  DEBUG and $file and warn "Pull-parsing $file (process number $process_no)\n";
-  $w->{'pod_title'} = $p->get_short_title || $title || $file;
+  DEBUG and warn "Pull-parsing $file (process number $process_no)\n";
+  $w->{'pod_title'} = $p->get_short_title || $file;
 
   my($token, $tagname, $style);
   my $last_update = Tk::timeofday();
-  my $current_line;
   while($token = $p->get_token) {
 
     DEBUG > 7 and warn " t:", $token->dump, "\n";
-    if($token->can("attr_hash") && exists $token->attr_hash->{start_line}) {
-      $current_line = $token->attr_hash->{start_line};
-    }
 
     if($token->is_text) {
-      DEBUG > 10 and warn " ->pod_text( ", $token->text, ",", $current_line, ")\n";
-      $w->pod_text( $token, $current_line );
+      DEBUG > 10 and warn " ->pod_text( ", $token->text, ")\n";
+      $w->pod_text( $token );
 
     } elsif($token->is_start) {
       ($tagname = $token->tagname ) =~ tr/-:./__/;
@@ -111,7 +103,7 @@ sub process { # main routine: non-handler
 
   undef $p;
   delete $w->{'pod_parser'};
-  DEBUG and $file and warn "Done rendering $file\n";
+  DEBUG and warn "Done rendering $file\n";
 
   $w->parent->add_section_menu if $w->parent->can('add_section_menu');
   $w->Callback('-poddone', $file);
@@ -123,7 +115,7 @@ sub process { # main routine: non-handler
 ###########################################################################
 
 sub pod_text {
-  my($w, $t, $current_line) = @_;
+  my($w, $t) = @_;
   if( $w->{'pod_in_X'} ) {
     # no-op
   } else {
@@ -134,8 +126,8 @@ sub pod_text {
       join('/', %attributes), "\n";
 
     my $startpoint = $w->index('end -1c');
-    $w->insert( 'end -1c', $t->text, "start_line_" . $current_line );
-   
+    $w->insert( 'end -1c', $t->text );
+    
     $w->tag(
       'add',
       $w->tag_for(\%attributes),
@@ -164,7 +156,6 @@ sub pod_end_Document {
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 sub nlnl { $_[0]->insert( 'end -1c', "\n\n" ); $_[0]; }
-sub nl { $_[0]->insert( 'end -1c', "\n" ); $_[0]; }
 
 sub fake_unget_bold_text {
   require Pod::Simple::PullParserStartToken;
@@ -189,13 +180,11 @@ sub pod_end_Para        { $_[0]->_indent($_[2]); $_[0]->nlnl }
 sub pod_end_Verbatim    { $_[0]->_indent($_[2]); $_[0]->nlnl }
 sub pod_end_item_bullet { $_[0]->_indent($_[2]); $_[0]->nlnl }
 sub pod_end_item_number { $_[0]->_indent($_[2]); $_[0]->nlnl }
-sub pod_end_item_text   { $_[0]->_indent($_[2]); $_[0]->nl }
-
-sub pod_end_over_text   { $_[0]->nl } # XXX ok?
+sub pod_end_item_text   { $_[0]->_indent($_[2]); $_[0]->nlnl }
 
 sub _indent {
   my ($w, $start) = @_;
-
+  
   my $indent = 0;
   foreach my $s (@{ $w->{'style_stack'} }) {
     $indent += $s->[1] if @$s and $s->[0] eq 'indent';
@@ -265,7 +254,6 @@ sub tag_for {
         '-font' => $font_name,
         ('none' eq ($attr->{'wrap'} || '')) ? ('-wrap' => 'none') : (),
         $attr->{'underline'} ? ('-underline' => 'true') : (),
-	(map { defined $attr->{$_} ? ("-$_" => $attr->{$_}) : () } qw(background borderwidth relief lmargin1 rmargin)),
       );
       DEBUG > 10 and sleep 1;
       $canonical_form;
@@ -330,7 +318,6 @@ sub pod_end_L   {
     $w->tag('configure', $tag, '-underline' => 1, '-foreground' => 'darkgreen' );
   }
   $w->tag('add', $tag, $_[2] ,'end -1c');
-  $w->tag('add', 'pod_link', $_[2] ,'end -1c'); # needed for ButtonRelease-2 hack, see Pod/Text.pm
 
   return;
 }
@@ -402,12 +389,12 @@ Tk::Pod::SimpleBridge -- render Pod::Simple events to a Tk::Pod window
 
 =head1 DESCRIPTION
 
-This class contains methods that L<Tk::Pod> (specifically L<Tk::Pod::Text>)
+This class contains methods that Tk::Pod (specifically Tk::Pod::Text)
 uses to render a pod page's text into its window.  It uses L<Pod::Simple>
 (specifically L<Pod::Simple::PullParser>) to do the parsing.
 
-L<Tk::Pod> used to use Tk::Parse (a snapshot of an old old Pod-parser)
-to do the Pod-parsing.  But it doesn't anymore -- it now uses L<Pod::Simple>
+Tk::Pod used to use Tk::Parse (a snapshot of an old old Pod-parser)
+to do the Pod-parsing.  But it doesn't anymore -- it now uses Pod::Simple
 via this module.
 
 =head1 COPYRIGHT AND DISCLAIMERS
@@ -427,6 +414,7 @@ Sean M. Burke <F<sburke@cpan.org>>, with bits of Tk code cribbed from
 the old Tk::Pod::Text code that Nick Ing-Simmons
 <F<nick@ni-s.u-net.com>> originally wrote.
 
-Current maintainer is Slaven ReziE<0x0107> <F<slaven@rezic.de>>.
+Current maintainer is Slaven Rezic <F<slaven@rezic.de>>.
 
 =cut
+
